@@ -421,10 +421,30 @@ def PrecomputeLikelihoodTerms(event_time_geo, t_window, P, data_dict,
         else:
           rholms_intp[det] = None
 
+    guess_snr=None
+    if True: 
+      # estimate peak snr based on rholms.  
+      #   - Note U, Q are scaled to fiducial distance.  Likelihood eqution (Pankow et al) :  -0.25 x^2 U + x Q = L where x=1/d
+      #   - complete square, maximize in x gives us estimate.  
+      #   - don't do precisely correctly, since we're not using sky location, emission direction, or detector response factors, nor coherence between modes. Add in quadrature
+      rho_max = 0
+      
+      for ifo in rholms:
+        rho_max_ifo = 0
+        for mode in rholms[ifo]:
+          rho_max_ifo= np.max(np.abs(rholms[ifo][mode].data.data))
+          delta_here= rho_max_ifo**2/np.real(crossTerms[ifo][(mode,mode)])
+          if verbose:
+            print("  ... ", ifo, mode,rho_max_ifo,np.real(crossTerms[ifo][(mode,mode)]), delta_here)
+          rho_max+= delta_here
+      rho_max = np.sqrt(rho_max)/2.3  # guesstimate, keep in mind there are sky location terms, coherence, etc
+      print("SNR guess (internal, from det response) ", rho_max,rho_max**2/2)
+      guess_snr= rho_max
+
     if not ROM_use_basis:
-            return rholms_intp, crossTerms, crossTermsV,  rholms, None
+            return rholms_intp, crossTerms, crossTermsV,  rholms, guess_snr, None
     else:
-            return rholms_intp, crossTerms, crossTermsV,  rholms, acatHere   # labels are misleading for use_rom_basis
+            return rholms_intp, crossTerms, crossTermsV,  rholms, guess_snr,  acatHere    # labels are misleading for use_rom_basis
 
 def ReconstructPrecomputedLikelihoodTermsROM(P,acat_rom,rho_intp_rom,crossTerms_rom, crossTermsV_rom, rho_rom,verbose=True):
         """
@@ -1701,7 +1721,7 @@ def _factored_lnL_helper(kappa_sq, rho_sq):
     return kappa_sq - 0.5 * rho_sq
 
 
-def  DiscreteFactoredLogLikelihoodViaArrayVectorNoLoop(tvals, P_vec, lookupNKDict, rholmsArrayDict, ctUArrayDict,ctVArrayDict,epochDict,Lmax=2,array_output=False,xpy=np, loglikelihood=_factored_lnL_helper):
+def  DiscreteFactoredLogLikelihoodViaArrayVectorNoLoop(tvals, P_vec, lookupNKDict, rholmsArrayDict, ctUArrayDict,ctVArrayDict,epochDict,Lmax=2,array_output=False,xpy=np, loglikelihood=_factored_lnL_helper,return_lnLt=False):
     """
     DiscreteFactoredLogLikelihoodViaArray uses the array-ized data structures to compute the log likelihood,
     either as an array vs time *or* marginalized in time. 
@@ -1905,6 +1925,8 @@ def  DiscreteFactoredLogLikelihoodViaArrayVectorNoLoop(tvals, P_vec, lookupNKDic
 
     # Take exponential of the log likelihood in-place.
     lnLmax  = xpy.max(lnL_t)
+    if return_lnLt:
+      return lnL_t - lnLmax
     L_t = xpy.exp(lnL_t - lnLmax, out=lnL_t)
 
     L = simps(L_t, dx=deltaT, axis=-1)
